==> haskell-http-download-0.1.0.0-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-download
version: 0.1.0.0
id: http-download-0.1.0.0-I6Jgj110sx47aRp84t69TD
key: http-download-0.1.0.0-I6Jgj110sx47aRp84t69TD
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Verified downloads with retries
category: Development
abi: f0b2c6f5b5d331c213dcad9bcd4e2fe8
exposed: True
exposed-modules:
    Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules: Paths_http_download
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-download-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-download-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-download-0.1.0.0
hs-libraries: HShttp-download-0.1.0.0-I6Jgj110sx47aRp84t69TD
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 conduit-1.3.1.1-CfM5hRP1Ia6GpnibXcmH9G
    conduit-extra-1.3.4-ApR2ZiAyfO54oTAYFYfASb
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    cryptonite-conduit-0.2.2-ITlHlOh3QYv9px9t4j8BGR directory-1.3.3.0
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    http-client-0.6.4-73LSh37vIvj1AryXK8OuVy
    http-conduit-2.3.7.1-60wciLoHNg8LdmlYZ1Jvhz
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    path-0.6.1-Dbf4RfDrHofHtc1bqSTwwN
    path-io-1.4.2-LC2bphiRDgqLbnvsCG1r2G
    retry-0.8.0.1-1nFgjSWZCgvG6N6kCMoJ9K
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    rio-prettyprint-0.1.0.0-JAD1qWV1ZUkEVIURfaM5Yw
haddock-interfaces: /usr/share/doc/haskell-http-download/html/http-download.haddock
haddock-html: /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-download-0.1.0.0-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-download
version: 0.1.0.0
id: http-download-0.1.0.0-JbG2gpTvEdbD0J13e3iE2P
key: http-download-0.1.0.0-JbG2gpTvEdbD0J13e3iE2P
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Verified downloads with retries
category: Development
abi: 1f0602bb7e1fdd11f9e3f465be32144e
exposed: True
exposed-modules:
    Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules: Paths_http_download
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-download-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-download-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-download-0.1.0.0
hs-libraries: HShttp-download-0.1.0.0-JbG2gpTvEdbD0J13e3iE2P
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 conduit-1.3.1.1-CfM5hRP1Ia6GpnibXcmH9G
    conduit-extra-1.3.4-ApR2ZiAyfO54oTAYFYfASb
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    cryptonite-conduit-0.2.2-ITlHlOh3QYv9px9t4j8BGR directory-1.3.3.0
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt filepath-1.4.2.1
    http-client-0.6.4-73LSh37vIvj1AryXK8OuVy
    http-conduit-2.3.7.1-G2w7vWPk1V4DF7fe0f7sBo
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    path-0.6.1-Dbf4RfDrHofHtc1bqSTwwN
    path-io-1.4.2-LC2bphiRDgqLbnvsCG1r2G
    retry-0.8.0.1-1nFgjSWZCgvG6N6kCMoJ9K
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    rio-prettyprint-0.1.0.0-JAD1qWV1ZUkEVIURfaM5Yw
haddock-interfaces: /usr/share/doc/haskell-http-download/html/http-download.haddock
haddock-html: /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
